@@ -3,7 +3,7 @@
 ########################################################################
 # Extension Manager/Repository config file for ext "wizard_crpages".
 #
-# Auto generated 25-11-2009 22:15
+# Auto generated 26-01-2011 20:08
 #
 # Manual updates:
 # Only the data in the array - everything else is removed by next
@@ -30,13 +30,13 @@ $EM_CONF[$_EXTKEY] = array(
 	'author' => 'Kasper Skaarhoj',
 	'author_email' => 'kasperYYYY@typo3.com',
 	'author_company' => 'Curby Soft Multimedia',
-	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:7:{s:36:"class.tx_wizardcrpages_webfunc_2.php";s:4:"838c";s:12:"ext_icon.gif";s:4:"f1c4";s:14:"ext_tables.php";s:4:"7e2d";s:13:"locallang.xml";s:4:"2e0e";s:17:"locallang_csh.xml";s:4:"c7d9";s:23:"cshimages/wizards_1.png";s:4:"d09d";s:23:"cshimages/wizards_2.png";s:4:"2824";}',
+	'version' => '1.1.0',
+	'_md5_values_when_last_written' => 'a:7:{s:36:"class.tx_wizardcrpages_webfunc_2.php";s:4:"af10";s:12:"ext_icon.gif";s:4:"c0a7";s:14:"ext_tables.php";s:4:"7e2d";s:13:"locallang.xml";s:4:"aef1";s:17:"locallang_csh.xml";s:4:"c7d9";s:23:"cshimages/wizards_1.png";s:4:"aa69";s:23:"cshimages/wizards_2.png";s:4:"294b";}',
 	'constraints' => array(
 		'depends' => array(
 			'func_wizards' => '',
 			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.3.0-4.3.99',
+			'typo3' => '4.4.0-0.0.0',
 		),
 		'conflicts' => array(
 		),
